@@ -1,7 +1,7 @@
 /*
  * gui-curses-main.c - main loop for Curses GUI
  *
- * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -31,14 +31,14 @@
 #include <time.h>
 
 #include "../../core/weechat.h"
-#include "../../core/wee-command.h"
-#include "../../core/wee-config.h"
-#include "../../core/wee-hook.h"
-#include "../../core/wee-log.h"
-#include "../../core/wee-string.h"
-#include "../../core/wee-utf8.h"
-#include "../../core/wee-util.h"
-#include "../../core/wee-version.h"
+#include "../../core/core-command.h"
+#include "../../core/core-config.h"
+#include "../../core/core-hook.h"
+#include "../../core/core-log.h"
+#include "../../core/core-signal.h"
+#include "../../core/core-string.h"
+#include "../../core/core-utf8.h"
+#include "../../core/core-version.h"
 #include "../../plugins/plugin.h"
 #include "../gui-main.h"
 #include "../gui-bar.h"
@@ -58,6 +58,9 @@
 #include "../gui-nicklist.h"
 #include "../gui-window.h"
 #include "gui-curses.h"
+#include "gui-curses-color.h"
+#include "gui-curses-key.h"
+#include "gui-curses-window.h"
 
 
 volatile sig_atomic_t gui_signal_sigwinch_received = 0;  /* sigwinch signal */
@@ -111,7 +114,7 @@ gui_main_get_password (const char **prompt, char *password, int size)
         /* enter */
         if (ch == '\n')
             break;
-        /* terminal lost or ctrl-C */
+        /* terminal lost or ctrl-c */
         if ((ch == ERR) || (ch == 3))
         {
             password[0] = 3;
@@ -147,8 +150,11 @@ gui_main_get_password (const char **prompt, char *password, int size)
  */
 
 void
-gui_main_signal_sigint ()
+gui_main_signal_sigint (int signo)
 {
+    /* make C compiler happy */
+    (void) signo;
+
     weechat_quit = 1;
 }
 
@@ -157,17 +163,14 @@ gui_main_signal_sigint ()
  */
 
 void
-gui_main_init ()
+gui_main_init (void)
 {
     struct t_gui_buffer *ptr_buffer;
-    struct t_gui_bar *ptr_bar;
-    struct t_gui_bar_window *ptr_bar_win;
     char title[256];
 
-#ifdef WEECHAT_HEADLESS
-    /* allow Ctrl-C to quit WeeChat in headless mode */
-    util_catch_signal (SIGINT, &gui_main_signal_sigint);
-#endif /* WEECHAT_HEADLESS */
+    /* allow ctrl-c to quit WeeChat in headless mode */
+    if (weechat_headless)
+        signal_catch (SIGINT, &gui_main_signal_sigint);
 
     initscr ();
 
@@ -236,24 +239,8 @@ gui_main_init ()
             }
         }
 
-        /*
-         * create bar windows for root bars (they were read from config,
-         * but no window was created, GUI was not initialized)
-         */
-        for (ptr_bar = gui_bars; ptr_bar; ptr_bar = ptr_bar->next_bar)
-        {
-            if ((CONFIG_INTEGER(ptr_bar->options[GUI_BAR_OPTION_TYPE]) == GUI_BAR_TYPE_ROOT)
-                && (!ptr_bar->bar_window))
-            {
-                gui_bar_window_new (ptr_bar, NULL);
-            }
-        }
-        for (ptr_bar_win = gui_windows->bar_windows;
-             ptr_bar_win; ptr_bar_win = ptr_bar_win->next_bar_window)
-        {
-            gui_bar_window_calculate_pos_size (ptr_bar_win, gui_windows);
-            gui_bar_window_create_win (ptr_bar_win);
-        }
+        /* switch to buffer */
+        gui_window_switch_to_buffer (gui_current_window, ptr_buffer, 0);
     }
 
     if (CONFIG_BOOLEAN(config_look_mouse))
@@ -269,62 +256,20 @@ gui_main_init ()
  */
 
 void
-gui_main_signal_sigwinch ()
+gui_main_signal_sigwinch (int signo)
 {
+    /* make C compiler happy */
+    (void) signo;
+
     gui_signal_sigwinch_received = 1;
 }
 
-/*
- * Callback for signals received that will make WeeChat quit.
- */
-
-void
-gui_main_handle_quit_signals ()
-{
-    char str_signal[32], str_weechat_signal[64];
-    int rc;
-
-    switch (weechat_quit_signal)
-    {
-        case SIGHUP:
-            snprintf (str_signal, sizeof (str_signal), "SIGHUP");
-            break;
-        case SIGQUIT:
-            snprintf (str_signal, sizeof (str_signal), "SIGQUIT");
-            break;
-        case SIGTERM:
-            snprintf (str_signal, sizeof (str_signal), "SIGTERM");
-            break;
-        default:
-            str_signal[0] = '\0';
-            break;
-    }
-
-    if (str_signal[0])
-    {
-        snprintf (str_weechat_signal, sizeof (str_weechat_signal),
-                  "signal_%s", str_signal);
-        string_tolower (str_weechat_signal);
-        rc = hook_signal_send (str_weechat_signal,
-                               WEECHAT_HOOK_SIGNAL_STRING, NULL);
-        if ((rc != WEECHAT_RC_OK_EAT) && !weechat_quit)
-        {
-            log_printf (_("Signal %s received, exiting WeeChat..."),
-                        str_signal);
-            (void) hook_signal_send ("quit", WEECHAT_HOOK_SIGNAL_STRING, NULL);
-            weechat_quit = 1;
-        }
-    }
-
-    weechat_quit_signal = 0;
-}
-
 /*
  * Displays infos about ncurses lib.
  */
 
 void
-gui_main_debug_libs ()
+gui_main_debug_libs (void)
 {
 #if defined(NCURSES_VERSION) && defined(NCURSES_VERSION_PATCH)
     gui_chat_printf (NULL, "    ncurses: %s (patch %d)",
@@ -339,7 +284,7 @@ gui_main_debug_libs ()
  */
 
 void
-gui_main_refreshes ()
+gui_main_refreshes (void)
 {
     struct t_gui_window *ptr_win;
     struct t_gui_buffer *ptr_buffer;
@@ -446,7 +391,7 @@ gui_main_refreshes ()
  */
 
 void
-gui_main_loop ()
+gui_main_loop (void)
 {
     struct t_hook *hook_fd_keyboard;
     int send_signal_sigwinch;
@@ -455,7 +400,10 @@ gui_main_loop ()
 
     /* catch SIGWINCH signal: redraw screen */
     if (!weechat_headless)
-        util_catch_signal (SIGWINCH, &gui_main_signal_sigwinch);
+    {
+        gui_signal_sigwinch_received = 1;
+        signal_catch (SIGWINCH, &gui_main_signal_sigwinch);
+    }
 
     /* hook stdin (read keyboard) */
     if (weechat_headless)
@@ -511,13 +459,11 @@ gui_main_loop ()
         hook_process_exec ();
 
         /* handle signals received */
-        if (weechat_quit_signal > 0)
-            gui_main_handle_quit_signals ();
+        signal_handle ();
     }
 
     /* remove keyboard hook */
-    if (hook_fd_keyboard)
-        unhook (hook_fd_keyboard);
+    unhook (hook_fd_keyboard);
 }
 
 /*
@@ -557,8 +503,7 @@ gui_main_end (int clean_exit)
         gui_filter_free_all ();
 
         /* free clipboard buffer */
-        if (gui_input_clipboard)
-            free (gui_input_clipboard);
+        free (gui_input_clipboard);
 
         /* delete layouts */
         gui_layout_remove_all ();
