@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,16 +14,22 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_FIFO_H
-#define __WEECHAT_FIFO_H 1
+#ifndef WEECHAT_PLUGIN_FIFO_H
+#define WEECHAT_PLUGIN_FIFO_H
 
 #define weechat_plugin weechat_fifo_plugin
 #define FIFO_PLUGIN_NAME "fifo"
+#define FIFO_PLUGIN_PRIORITY 9000
 
 extern struct t_weechat_plugin *weechat_fifo_plugin;
+extern int fifo_quiet;
+extern int fifo_fd;
 extern char *fifo_filename;
 
-#endif /* __WEECHAT_FIFO_H */
+extern void fifo_create (void);
+extern void fifo_remove (void);
+
+#endif /* WEECHAT_PLUGIN_FIFO_H */
