@@ -1,7 +1,7 @@
 /*
  * weechat-guile.c - guile (scheme) plugin for WeeChat
  *
- * Copyright (C) 2011-2024 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2011-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -116,13 +116,12 @@ char *guile_action_autoload_list = NULL;
  */
 
 void
-weechat_guile_output_flush ()
+weechat_guile_output_flush (void)
 {
     const char *ptr_command;
     char *temp_buffer, *command;
-    int length;
 
-    if (!*guile_buffer_output[0])
+    if (!(*guile_buffer_output)[0])
         return;
 
     /* if there's no buffer, we catch the output, so there's no flush */
@@ -149,12 +148,11 @@ weechat_guile_output_flush ()
             }
             else
             {
-                length = 1 + strlen (temp_buffer) + 1;
-                command = malloc (length);
-                if (command)
+                if (weechat_asprintf (&command,
+                                      "%c%s",
+                                      temp_buffer[0],
+                                      temp_buffer) >= 0)
                 {
-                    snprintf (command, length, "%c%s",
-                              temp_buffer[0], temp_buffer);
                     weechat_command (guile_eval_buffer,
                                      (command[0]) ? command : " ");
                     free (command);
@@ -285,7 +283,7 @@ weechat_guile_hashtable_to_alist (struct t_hashtable *hashtable)
 /*
  * Converts a guile alist to a WeeChat hashtable.
  *
- * Note: hashtable must be free after use.
+ * Note: hashtable must be freed after use.
  */
 
 struct t_hashtable *
@@ -686,7 +684,7 @@ weechat_guile_unload_name (const char *name)
  */
 
 void
-weechat_guile_unload_all ()
+weechat_guile_unload_all (void)
 {
     while (guile_scripts)
     {
@@ -742,13 +740,15 @@ weechat_guile_eval (struct t_gui_buffer *buffer, int send_to_buffer_as_input,
                     int exec_commands, const char *code)
 {
     void *func_argv[1], *result;
+    int old_guile_quiet;
 
     if (!guile_script_eval)
     {
+        old_guile_quiet = guile_quiet;
         guile_quiet = 1;
         guile_script_eval = weechat_guile_load (WEECHAT_SCRIPT_EVAL_NAME,
                                                 GUILE_EVAL_SCRIPT);
-        guile_quiet = 0;
+        guile_quiet = old_guile_quiet;
         if (!guile_script_eval)
             return 0;
     }
@@ -777,9 +777,10 @@ weechat_guile_eval (struct t_gui_buffer *buffer, int send_to_buffer_as_input,
 
     if (!weechat_config_boolean (guile_config_look_eval_keep_context))
     {
+        old_guile_quiet = guile_quiet;
         guile_quiet = 1;
         weechat_guile_unload (guile_script_eval);
-        guile_quiet = 0;
+        guile_quiet = old_guile_quiet;
         guile_script_eval = NULL;
     }
 
@@ -796,7 +797,7 @@ weechat_guile_command_cb (const void *pointer, void *data,
                           int argc, char **argv, char **argv_eol)
 {
     char *ptr_name, *ptr_code, *path_script;
-    int i, send_to_buffer_as_input, exec_commands;
+    int i, send_to_buffer_as_input, exec_commands, old_guile_quiet;
 
     /* make C compiler happy */
     (void) pointer;
@@ -855,6 +856,7 @@ weechat_guile_command_cb (const void *pointer, void *data,
                  || (weechat_strcmp (argv[1], "reload") == 0)
                  || (weechat_strcmp (argv[1], "unload") == 0))
         {
+            old_guile_quiet = guile_quiet;
             ptr_name = argv_eol[2];
             if (strncmp (ptr_name, "-q ", 3) == 0)
             {
@@ -884,7 +886,7 @@ weechat_guile_command_cb (const void *pointer, void *data,
                 /* unload guile script */
                 weechat_guile_unload_name (ptr_name);
             }
-            guile_quiet = 0;
+            guile_quiet = old_guile_quiet;
         }
         else if (weechat_strcmp (argv[1], "eval") == 0)
         {
@@ -1243,6 +1245,7 @@ int
 weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 {
     char str_version[128];
+    int old_guile_quiet;
 
     /* make C compiler happy */
     (void) argc;
@@ -1281,7 +1284,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     /*
      * prevent guile to use its own gmp allocator, because it can conflict
      * with other plugins using GnuTLS like relay, which can crash WeeChat
-     * on unload (or exit); this is not needed any more with Guile ≥ 3.0.8
+     * on unload (or exit); this is not needed anymore with Guile ≥ 3.0.8
      */
     scm_install_gmp_memory_functions = 0;
 #endif /* defined(HAVE_GUILE_GMP_MEMORY_FUNCTIONS) && (SCM_MAJOR_VERSION < 3 || (SCM_MAJOR_VERSION == 3 && SCM_MINOR_VERSION == 0 && SCM_MICRO_VERSION < 8)) */
@@ -1316,11 +1319,13 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     guile_data.callback_signal_debug_dump = &weechat_guile_signal_debug_dump_cb;
     guile_data.callback_signal_script_action = &weechat_guile_signal_script_action_cb;
     guile_data.callback_load_file = &weechat_guile_load_cb;
+    guile_data.init_before_autoload = NULL;
     guile_data.unload_all = &weechat_guile_unload_all;
 
+    old_guile_quiet = guile_quiet;
     guile_quiet = 1;
     plugin_script_init (weechat_guile_plugin, &guile_data);
-    guile_quiet = 0;
+    guile_quiet = old_guile_quiet;
 
     plugin_script_display_short_list (weechat_guile_plugin,
                                       guile_scripts);
@@ -1336,7 +1341,10 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
 int
 weechat_plugin_end (struct t_weechat_plugin *plugin)
 {
+    int old_guile_quiet;
+
     /* unload all scripts */
+    old_guile_quiet = guile_quiet;
     guile_quiet = 1;
     if (guile_script_eval)
     {
@@ -1344,7 +1352,7 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
         guile_script_eval = NULL;
     }
     plugin_script_end (plugin, &guile_data);
-    guile_quiet = 0;
+    guile_quiet = old_guile_quiet;
 
     /* unprotect module */
     weechat_guile_catch (scm_gc_unprotect_object, (void *)guile_module_weechat);
