@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,24 +14,28 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_PLUGIN_CONFIG_H
-#define __WEECHAT_PLUGIN_CONFIG_H 1
+#ifndef WEECHAT_PLUGIN_PLUGIN_CONFIG_H
+#define WEECHAT_PLUGIN_PLUGIN_CONFIG_H
 
 #define PLUGIN_CONFIG_NAME "plugins"
+#define PLUGIN_CONFIG_PRIO_NAME "100000|plugins"
 
-extern struct t_config_file *plugin_config;
+extern struct t_config_file *plugin_config_file;
 extern struct t_config_option *plugin_options;
 
 extern struct t_config_option *plugin_config_search (const char *plugin_name,
                                                      const char *option_name);
 extern int plugin_config_set (const char *plugin_name, const char *option_name,
                               const char *value);
-extern void plugin_config_init ();
-extern int plugin_config_read ();
-extern int plugin_config_write ();
-extern void plugin_config_end ();
+extern void plugin_config_set_desc (const char *plugin_name,
+                                    const char *option_name,
+                                    const char *description);
+extern void plugin_config_init (void);
+extern int plugin_config_read (void);
+extern int plugin_config_write (void);
+extern void plugin_config_end (void);
 
-#endif /* __WEECHAT_PLUGIN_CONFIG_H */
+#endif /* WEECHAT_PLUGIN_PLUGIN_CONFIG_H */
