@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003-2010 Sebastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2025 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -14,11 +14,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#ifndef __WEECHAT_RELAY_UPGRADE_H
-#define __WEECHAT_RELAY_UPGRADE_H 1
+#ifndef WEECHAT_PLUGIN_RELAY_UPGRADE_H
+#define WEECHAT_PLUGIN_RELAY_UPGRADE_H
 
 #define RELAY_UPGRADE_FILENAME "relay"
 
@@ -26,10 +26,12 @@
 
 enum t_relay_upgrade_type
 {
-    RELAY_UPGRADE_TYPE_RELAY = 0,
+    RELAY_UPGRADE_TYPE_CLIENT = 0,
+    RELAY_UPGRADE_TYPE_RAW_MESSAGE,
+    RELAY_UPGRADE_TYPE_SERVER,
 };
 
-extern int relay_upgrade_save ();
-extern int relay_upgrade_load ();
+extern int relay_upgrade_save (int force_disconnected_state);
+extern int relay_upgrade_load (void);
 
-#endif /* __WEECHAT_RELAY_UPGRADE_H */
+#endif /* WEECHAT_PLUGIN_RELAY_UPGRADE_H */
